/**
 * The AgilityPotion class represents a potion that can be consumed by the kobold,
 * which increases its agility stat.
 */
function AgilityPotion() {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;

    var itemName = "Agility Potion";
    var itemDescription = "A small glass vial. Green liquid sloshes within. The label on the side says that it'll make you more agile.";
    var baseValue = 50;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the consume popup contents.
     * @returns {string} The consume popup contents.
     */
    function buildPopupContents() {
        return `<h2 class="subtitle">${itemName}</h2>
                <div class="text">
                    You pop the lid of the potion, bring it to your snout, and cautiously sniff the contents. 
                    The green fluid within smells like the forest.
                    Like a pine tree, to be more precise. 
                    You quite like the scent.
                    Emboldened by the mild fragrance, you lower the vial to your slightly parted lips, before tipping it backwards, 
                    along with your head, letting the contents flood into your mouth.
                </div>
                <div class="text">
                    The fluid seems quite a bit more viscous than you'd originally anticipated, oozing from the glass container like a thick slime.
                    While the taste isn't all that bad, the snot-like consistency almost makes you gag. 
                    The green goop sticks to your gums, your teeth and the top of your mouth.
                    You have a hard time getting it down your throat.
                </div>
                <div class="text">
                    Still, you force yourself to gulp down as much of the potion as you can.
                    Two big mouthfuls later, most of the green liquid has either made its way to your stomach, or is left lingering in your muzzle.
                    Content with your own efforts, you discard the near-empty vial.
                </div>
                <div class="text">
                    The leftover goop in your mouth rapidly dissolves, mixing with your saliva and becoming far easier to swallow.
                    You immediately feel the effects of the potion beginning to kick in.
                    While no visible changes occur, your body feels lighter, more nimble.
                </div>
                <div class="text">
                    <span class="bold">You have gained 1 agility.</span>
                </div>`;
    }

    // PUBLIC MEMBERS \\        this.public = "test";

    // ITEM-REQUIRED item-enum for construction purposes.
    this.id = ItemEnum.AGILITY_POTION;
    // ITEM-REQUIRED type-enum for tooltip purposes.
    this.type = ItemTypeEnum.CONSUMABLE;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * ITEM-REQUIRED function.
     * Builds and returns the name of this item.
     * @param {boolean} caps Whether or not the name should be capitalized.
     * @returns {string} The name of this item.
     */
    this.name = function (caps) {
        var toReturn = caps ? itemName : itemName.toLowerCase();
        return toReturn;
    };

    /**
     * ITEM-REQUIRED function.
     * Builds and returns the description of this item.
     * @returns {string} The description of this item.
     */
    this.description = function () {
        return itemDescription;
    };

    /**
     * ITEM-REQUIRED function.
     * Calculates and returns the price (= value) of this item.
     * @returns {int} The price of this pair of pants, in coins.
     */
    this.price = function () {
        return baseValue;
    };

    /**
     * ITEM-REQUIRED function.
     * Builds and returns a custom tooltip style for this item.
     * @returns {string} The custom style.
     */
    this.toolTipStyle = function () {
        return "width: 200px;";
    };

    /**
     * CONSUMABLE-REQUIRED function.
     * Consumes this consumable.
     */
    this.consume = function () {
        var agi = global.kobold.stats.get(StatsEnum.AGILITY);
        var maxed = (agi >= global.kobold.stats.statMax);
        if (maxed) {
            global.ui.showFullscreenPopup(`<div class="text">You are already as agile as you're ever going to get. The potion does nothing!</div>`);
        } else {
            global.kobold.stats.increaseStat(StatsEnum.AGILITY, 1);
            global.ui.showFullscreenPopup(buildPopupContents());
        }
    };

    /**
     * ITEM-REQUIRED function.
     * Loads this object from a type-stripped version thereof.
     * @param {AgilityPotion-stripped} potion An AgilityPotion object, stripped of private members and all functions.
     */
    this.load = function (potion) {

    };
}
