/**
 * The WoolSweater class represents a wool sweater that can be worn by the kobold.
 */
function WoolSweater() {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;

    var itemName = "Wool Sweater";
    var itemDescription = `A warm, comfortable, snug woolen sweater. Keeps you warm at night, and is thick enough to offer a small bit of cushioning protection.`;

    var rippedName = `Ripped Wool Sweater`;
    var rippedDescription = `Once a warm sweater, now nothing more than a bunch of torn rags. 
                             You can still wear it, but it won't keep you nearly as warm as when it wasn't ripped in half`;

    var baseValue = 25;
    var offensiveValue = 0;
    var defensiveValue = 3;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    // PUBLIC MEMBERS \\        this.public = "test";

    // ITEM-REQUIRED item-enum for construction purposes.
    this.id = ItemEnum.WOOLSWEATER;
    // ITEM-REQUIRED type-enum for tooltip purposes.
    this.type = ItemTypeEnum.GEAR;
    // GEAR-REQUIRED slot-enum.
    this.slot = SlotEnum.SHIRT;

    // Whether or not the sweater is ripped.
    this.ripped = false;


    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * ITEM-REQUIRED function.
     * Builds and returns the name of this item.
     * @param {boolean} caps Whether or not the name should be capitalized.
     * @returns {string} The name of this item.
     */
    this.name = function (caps) {
        var name = that.ripped ? rippedName : itemName;
        var toReturn = caps ? name : name.toLocaleLowerCase();
        return toReturn;
    };

    /**
     * ITEM-REQUIRED function.
     * Builds and returns the description of this item.
     * @returns {string} The description of this item.
     */
    this.description = function () {
        var description = that.ripped ? rippedDescription : itemDescription;
        return description;
    };

    /**
     * ITEM-REQUIRED function.
     * Calculates and returns the price (= value) of this item.
     * @returns {int} The price of this pair of pants, in coins.
     */
    this.price = function () {
        var price = that.ripped ? baseValue - 20 : baseValue;
        return price;
    };

    /**
     * ITEM-REQUIRED function.
     * Builds and returns a custom tooltip style for this item.
     * @returns {string} The custom style.
     */
    this.toolTipStyle = function () {
        var style = that.ripped ? "width: 230px;" : "width: 205px;";
        return style;
    };

    /**
     * GEAR-REQUIRED function.
     * Calculates and returns the offensive value of this piece of gear.
     * @returns {int} The offensive value of this piece of gear.
     */
    this.offence = function () {
        return offensiveValue;
    };

    /**
     * GEAR-REQUIRED function.
     * Calculates and returns the defensive value of this piece of gear.
     * @returns {int} The defensive value of this piece of gear.
     */
    this.defence = function () {
        var defence = that.ripped ? defensiveValue - 2 : defensiveValue;
        return defence;
    };

    /**
     * SHIRT-required function.
     * Returns true if the shirt covers the groin, and false otherwise.
     * @returns {boolean} True if the shirt covers the groin, and false otherwise.
     */
    this.coversGroin = function () {
        return false;
    };

    /**
     * SHIRT-required function.
     * Returns true if the shirt covers the rear, and false otherwise.
     * @returns {boolean} True if the shirt covers the rear, and false otherwise.
     */
    this.coversRear = function () {
        return false;
    };

    /**
     * SHIRT-required function.
     * Returns true if the shirt covers the chest, and false otherwise.
     * @returns {boolean} True if the shirt covers the chest, and false otherwise.
     */
    this.coversChest = function () {
        return true;
    };

    /**
     * SHIRT-required function.
     * Returns true if the shirt can be torn, and false otherwise.
     * @returns {boolean} True if the shirt can be torn, and false otherwise.
     */
    this.canBeTorn = function () {
        return true;
    };

    /**
     * SHIRT-required function.
     * Returns true if the shirt is a mismatch for the kobold's current gender.
     * @returns {boolean} True if the shirt is a mismatch for the kobold's current gender, false otherwise.
     */
    this.wrongGender = function () {
        return false; // Wool sweater is for everyone.
    };

    /**
     * ITEM-REQUIRED function.
     * Loads this object from a type-stripped version thereof.
     * @param {PaddedLeatherShirt-stripped} shirt A PaddedLeatherShirt object, stripped of private members and all functions.
     */
    this.load = function (shirt) {
        if (shirt.ripped) {
            that.ripped = shirt.ripped;
        }
    };
}

function RippedWoolSweater() {
    var sweater = new WoolSweater();
    sweater.ripped = true;
    return sweater;
}
