/**
 * Hit success section of the unknown scene.
 * @param {ForestController} controller The forest controller.
 */
function ForestUnknownHitSuccess(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var continueId = `woodsContinueButton`;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var weapon = ctrl.unknown.weapon();
        var weaponPopup = global.kobold.inventory.createItemWithTooltip(weapon);
        var toReturn = `[p]
                            The horrific creature sends another one of its tentacles towards you,
                            but just like before, you manage to strike it down before it can reach you.
                            Aggravated, the bush's next assault consists of two separate tendrils which both attempt to hit you at once.
                            You dodge one, bash the other and then decide to go on the offensive.
                        [/p]
                        [p]
                            With an overhead swing, you [b]plow[/b] your weapon into the monster's center mass.
                            While the smack was exceedingly effective, the biological terror instantly retalliates with a sharp, 
                            barbed [b]whip[/b] to your back, strong enough to draw blood.
                            You grunt in pain and take a step backwards.
                        [/p]
                        [p]
                            You've managed to hurt it, but it, in turn, hurt you,
                            and you doubt that you can outlive this monstrosity in a trading blows contest.
                            Instead of resuming your reckless assault, you fall back into the pattern of deflecting its attacks.
                            Surely, if you beat enough of these damned tentacles, the entire thing'll just [i]have to[/i] give up at some point, right?
                        [/p]
                        [p]
                            You defend yourself from hit upon hit, using your ${weaponPopup} as both a shield and an offensive tool.
                            A few of the more tricky swipes get through your parrying stance, yet they never manage to do more than [i]scrape[/i] you.
                            As the sun, which had already begun its descent when you first came upon the bush, makes way for nighttime,
                            the two of you are [i]still[/i] fighting, both you and the monster driven by sheer [b]determination[/b] and [b]stubbornness[/b].
                        [/p]
                        [p]
                            Neither of you wants to back down at this point.
                            You're panting loudly, covered in a myriad of small cuts and scrapes, a few of which are bleeding, but nothing too severe.
                            The plant is leaking sap from most of its appendages, a few of which lie limply on the forest floor.
                            Perhaps it had hoped the darkness would give it an advantage, but as a kobold, your nightvision is superb.
                            The both of you realize this [b]is[/b] going to end shortly, one way or the other.
                        [/p]
                        [p]
                            A short, unnerving stillness ensues.
                            Then, the plant launches its final attack, its two remaining unscathed tendrils lunging at you.
                            You bash one to the side, but then the creature manages to wrap the last of its tentacles around your wrist,
                            painfully driving the thorns that cover it into your flesh.
                        [/p]
                        [p]
                            You scream out in pain, dropping your ${weaponPopup}.
                            A few of the less wounded tendrils seem to spring alive anew, as though the bush is encouraged by its own success.
                            But you are not yet beaten.
                            Far from it.
                        [/p]
                        [p]
                            You lean down, and harshly [b]bite[/b] the tendril holding your wrist, your sharp,
                            pointed teeth sinking through the plant matter with ease, completely [b]severing[/b] a large part of the beast's appendage,
                            the amputated segment instantly losing its grip, limply falling off of your forearm, dropping to the ground.
                            Sap squirts liberally from the now-blunt remainder of the tip of the tentacle.
                            The beast writhes, squirms and slowly backs away from you before slumping down to the ground, curling up into a messy ball of sap-leaking thorns.
                        [/p]
                        [p]
                            [c]
                                [b]
                                    You have beaten the tentacle monster!
                                [/b]
                            [/c]
                        [/p]
                        [p]
                            You crudely spit out the small piece of tendril you bit off, warily rising from your combat stance as you notice the creature's defeat.
                            You don't know whether you knocked it out, killed it, or whether it's [i]just pretending[/i] to be downed.
                            While keeping an eye on the vanquished monstrosity's body, you pick your ${weaponPopup} up off the ground, and begin to inspect your wounds.
                        [/p]
                        [p]
                            While nearly every inch of your entire form was scraped, cut or punctured during the fight, none of the individual wounds are [i]all that bad[/i].
                            Even your wrist, which, admittedly, the creature [i]did[/i] get a good, solid grip on, isn't bleeding too much.
                            The initial blow to your back was the worst, but [i]that[/i] pain has luckily already subsided.
                            You'll surely be sore in the morning, but right now, you're feeling just [i]fine[/i].
                        [/p]
                        [p]
                            You pick the tattered remains of your shirt, which you dropped to the ground during the fight.
                            You don the ${global.kobold.inventory.createItemWithTooltip(new RippedWoolSweater())}, not because it looks good, 
                            or because it'll protect you or keep you warm or anything, but as keepsake of you [b]beating the shit[/b] out of a scary deepwoods monster.
                        [/p]
                        [p]
                            The fight was rather disorienting, and with darkness having settled across the land, you doubt you can find your way back home.
                            While you are weary, you can't rest yet.
                            Not here, anyway.
                            Not near that [i]thing[/i].
                            You decide to press deeper into the woods.
                            Ultimately, you hope you'll be able to find your way back home,
                            but for now, you'd settle for a place to sleep.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.unknown.hasContinued();
        var choice = `<div class="choicecontainer">`;
        choice += `<button class="button bigbutton continuebutton" id="${continueId}" ${disabled ? "disabled" : ""}>`;
        choice += `Continue &gt;&gt`;
        choice += `</button>`;
        choice += `</div>`;
        return choice;
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = "forestUnknownHitSuccess";

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (!ctrl.unknown.yank.hit.toSuccess()) {
            return "";
        }

        global.ui.applyTheme("forest_night");
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += ctrl.unknown.yank.hit.successChange();
        part += buildChoice();
        part += `<span class="todo">There is no content beyond this point.</span>`;
        part += `</div>`;

        // BUILD CHILDREN HERE

        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (!ctrl.unknown.yank.hit.toSuccess()) {
            return;
        }
        // REGISTER CHILDREN HERE

        if (ctrl.unknown.hasContinued()) {
            return;
        }

        // REGISTER OWN LISTENERES HERE
    };
}
