/**
 * Arrival section of the Breeding Farm scene.
 * @param {BreedingFarmController} controller The Breeding Farm controller.
 */
function BreedingFarmArrival(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var barnId = "arrivalBarnButton";
    var houseId = "arrivalHouseButton";

    var toBarn = new BreedingBarn(ctrl);
    var toHouse = new BreedingHouse(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            You decide to pay a visit to the breeding farm, right across the rather broad dirt road from Seki's workshop.
                            Despite having visited Seki dozens of times, you've never really paid much mind to his [i]closest[/i] neighbour.
                            Mostly because you didn't want the old bird to get associated with a [i]thief[/i] such as yourself.
                            That would have hurt his business.
                            But now, you figure none of that really matters anymore.
                        [/p]
                        [p]
                            You walk down the small trail cutting through the extensive [i]front lawn[/i] of the breeding farm.
                            At a certain point, it splits into two.
                            One way goes towards the large, fancy house, which you presume whoever runs the farm lives in.
                            The other heads straight to the attached, dilapidated [i]barn[/i].
                            You reckon that's where the actual [i]work[/i] takes place at.
                            Separating living from your livelihood.
                            You wish you had the opportunity to do that.
                        [/p]
                        [p]
                            Alas, not everyone can be a natural born [i]whatever[/i]-breeder, or a farmer or a guard or something.
                            Some people are just [i]rotten apples[/i].
                            People like [b]you[/b].
                            You're a [b]thief[/b], and that's all you'll [b]ever[/b] be.
                            A no-good, lousy deadbeat mooching off of the success and the stupidity of others.
                            You'll [b]never[/b] become a knight.
                            And with your only [i]fence[/i] on the verge of dying,
                            and your debt to one of the major bosses of the shady underworld not yet repaid,
                            even your criminal career is rapidly reaching a dead end.
                            The future, for you, is looking grim.
                        [/p]
                        [p]
                            With a loud sigh, you set your gloomy thoughts aside, and approach the baroque house.
                            Stepping onto the porch, you reach upwards as high as you can, and firmly knock on the door.
                            Not once, not twice, but thrice.
                            As is customary in this part of the world.
                            Your courteous knocking, however, goes unresponded to.
                            You wait for several minutes, and even try a second time, but nobody answers your beckoning call.
                        [/p]
                        [p]
                            You come to the conclusion that the house must be empty.
                            You try opening the door, to see for yourself, but find it locked.
                            Peering through one of the windows, you notice a bunch of lit candles lining the walls.
                            Definitely not [i]abandoned[/i].
                            Whoever lives here must be in the barn, or out back somewhere.
                            Probably the former.
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the barn choice button.
     */
    function buildBarnChoice() {
        var disabled = ctrl.arrival.has() ? "disabled" : "";
        var isSelected = ctrl.arrival.get() === BreedingFarmArrivalChoice.BARN;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${barnId}" ${disabled} style="width: 180px;">Head to the barn</button>`;

        var tooltip = global.parser.parse(`It would be rude to prance about their property without making yourself known first.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 200px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the house choice button.
     */
    function buildHouseChoice() {
        var disabled = ctrl.arrival.has() ? "disabled" : "";
        var isSelected = ctrl.arrival.get() === BreedingFarmArrivalChoice.HOUSE;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${houseId}" ${disabled}>Break in</button>`;

        var tooltip = global.parser.parse(`Break into the house. You [i]are[/i] a thief, after all. <span class="todo">Unavailable.</span>`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 200px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer"><div class="inlinechoiceheader">You: </div>`;
        choice += buildHouseChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildBarnChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + barnId), $("#" + houseId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerBarnListener() {
        $("#" + barnId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.arrival.set(BreedingFarmArrivalChoice.BARN);
            loadNextPart(toBarn);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = "BFArrival";

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        global.ui.applyTheme("hamlet_day");
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += buildChoice();
        part += `</div>`;
        part += toBarn.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        toBarn.registerListeners();

        if (ctrl.arrival.has()) {
            return;
        }

        registerBarnListener();
    };
}

var BreedingFarmArrivalChoice = {
    BARN: 1,
    HOUSE: 2
};

