/**
 * Barn section of the farm scene.
 * @param {BreedingFarmController} controller The breeding farm controller.
 */
function NotBarnLootDownstairs(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var continueId = "notBarnLootDownstairsCButton";
    
    var next = new NotBarnLootDownstairsContinue(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var dead = global.kobold.history.shared.cassidy.dead;
        var toReturn = `[p]
                            You don't have time to check out the second floor.
                            You need to grab whatever you can and get the hell out of there.
                            You bolt around the house, looking for some [i]obvious[/i] things to steal.
                            Sadly, many drawers are locked, with no sign of any keys laying around.
                            The ones that [i]are[/i] unlocked are filled with worthless stuff.
                            Letters, utensils, a few cooking ingredients, nothing worth taking.
                        [/p]
                        [p]
                            You don't have time to check out the second floor.
                            You need to grab whatever you can and get the hell out of there.
                            You bolt around the house, looking for some [i]obvious[/i] things to steal.
                            Sadly, many drawers are locked, with no sign of any keys laying around.
                            The ones that [i]are[/i] unlocked are filled with worthless stuff.
                            Letters, utensils, a few cooking ingredients, nothing worth taking.
                        [/p]
                        [p]
                            On the verge of giving up hope on finding anything of value whatsoever, your avarice resurges as you enter the dining room.
                            The large rectangular table at the center of the room is set for dinner, a veritable [b]hoard[/b] of silver tableware ripe for the taking.
                            You begin collecting forks, spoons and breadknives, but before you manage to empty the entirety of the wooden surface, 
                            you hear a noise at the front door.
                            A voice calling out to Cassidy, trying to get her to wake up.
                        [/p]
                        [p]
                            Deciding not to take any chances, you cut your gathering short.
                            You sprint towards the back door, which is luckily unlocked,
                            and you silently slip outside, escaping the scene of the crime through the back yard.
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildContinueChoice() {
        var disabled = ctrl.postnotbarnloot.has() ? "disabled" : "";
        var isSelected = ctrl.postnotbarnloot.has();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildContinueChoice();
        choice += `</div>`;
        return choice;
    }
    
    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerContinueListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.postnotbarnloot.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = "notBarnLootDownstairs";

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (ctrl.notbarnloot.get() !== NotBarnLootChoice.DOWNSTAIRS) {
            return "";
        }
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += ctrl.notbarnDownstairsLootChange();
        part += buildChoice();
        part += next.build();
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (ctrl.notbarnloot.get() !== NotBarnLootChoice.DOWNSTAIRS) {
            return;
        }

        next.registerListeners();

        if (ctrl.postnotbarnloot.has()) {
            return;
        }

        registerContinueListener();
    };
}
