/**
 * Barn section of the farm scene.
 * @param {BreedingFarmController} controller The breeding farm controller.
 */
function NotBarnTeaDecline(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var continueId = "notBarnTeaDeclineContinueButton";

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            You politely decline the invitation, claiming that you have business to attend to.
                            Urgent business.
                            You're obviously lying,
                            but for the sake of [i]not[/i] making this entire ordeal [b]even more[/b] uncomfortable for the both of you,
                            the vixen decides not to ask what sort of a business a [i]kobold[/i] would have that can't stand to wait for an hour more,
                            let alone inquiring about why you stepped foot in her barn in the first place, if you have somewhere to be.
                        [/p]
                        [p]
                            Instead, a somewhat sad frown forms on her face.
                            Like you've not only rejected her as a lover, but as a [b]friend[/b].
                            She closes her eyes, presumably to stop herself from crying.
                            "[color=orange]Very well. Run along.[/color]"
                            With that said, she dismissively waves her hand, turns around and begins to walk away in silence, presumably to hide her sadness.
                        [/p]
                        [p]
                            You feel somewhat [i]guilty[/i] for making Cassidy upset, but at the same time, you never asked for any of this.
                            Internally conflicted, you decide not to stick around for much longer.
                            You return to the front door of the barn, and leave the ancient structure.
                        [/p]
                        [p]
                            A gust of fresh air makes you realize how [i]stale[/i] and [i]musty[/i] the air lingering in the barn was.
                            Like awakening from a drunken haze, your senses sharpen slightly.
                            As you begin to walk back to the center of the hamlet, you ponder the events that transpired.
                            While you [i]were[/i] a bit rude in declining the canine's tea-invitation,
                            surely that was no reason for the woman to burst out into tears, was it?
                            Maybe she was trying to [b]lure you in[/b], to guilt-trip you into humoring her.
                            Then again, she might just have been a nice lady trying to show you some hospitality.
                        [/p]
                        [p]
                            Alas, you will never know.
                            Unsure if you even [b]should[/b] be upset at yourself, you start to make your way towards Varanar,
                            hoping that not [i]everyone[/i] you meet will be as [i]thin-skinned[/i] as the vixen.
                            Your heart wouldn't be able to take upsetting half the city.
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.continued();
        var choice = `<div class="choicecontainer">`;
        choice += `<button class="button bigbutton continuebutton" id="${continueId}" ${disabled ? "disabled" : ""}>`;
        choice += `Continue &gt;&gt`;
        choice += `</button>`;
        choice += `</div>`;
        return choice;
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = "notBarnTeaDecline";

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (ctrl.tea.get() !== NotBarnTeaChoice.DECLINE) {
            return "";
        }
        global.ui.applyTheme("hamlet_day");
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += ctrl.teaDeclineChange();
        part += buildChoice();
        part += `<span class="todo">There is no content beyond this point.</span>`;
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (ctrl.tea.get() !== NotBarnTeaChoice.DECLINE) {
            return;
        }

        //toEager.registerListeners();

        if (ctrl.continued()) {
            return;
        }

        //registerContinueListener();
    };
}
