/**
 * Barn section of the farm scene.
 * @param {BreedingFarmController} controller The breeding farm controller.
 */
function NotBarnTeaDisagree(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var continueId = "notBarnTeaDisagreeButton";

    var next = new NotBarnTeaDisagreeContinue(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            No!
                            What Cassidy is doing is [b]wrong[/b], no matter how you look at it.
                            Take yourself, for example.
                            If she had her way, would you be in one of those pens right now?!
                            As you struggle to formulate a well-worded answer, the vixen finally manages to open the door to her house.
                            Without replying, you silently follow her inside, if just to give her a piece of your mind.
                        [/p]
                        [p]
                            Cassidy's house is as fancy on the inside as it is on the outside.
                            The entire place is well-lit by candles.
                            Various paintings of kobolds and canines alike line the walls.
                            You stay your tongue as she leads you to the den, where you get to take a seat in a luxurious padded chair.
                            The lack of words between the two of you continues as the vixen speechlessly wanders into the kitchen.
                            She knows you don't agree with her ways.
                            She'd have to be blind [i]not[/i] to be able to read your expression.
                            It is only when she returns with a pair of filled teacups, that you voice your concerns.
                        [/p]
                        [p]
                            The vulpine hands you your tea, and then sits down ever so daintily.
                            She sips her own drink, pinky finger fully extended.
                            She'd almost be lady-like if she weren't half-naked wearing cowboy attire.
                            [i]Almost[/i].
                        [/p]
                        [p]
                            After a long sip on her end, the two of you enter the most [i]philosophical[/i] debate you've [b]ever[/b] been a part of.
                            Well, at least it [i]seemed[/i] a bit more intricate than your usual dialogue.
                            But, as a kobold, even that isn't saying much.
                            You have to say, she makes a pretty darn decent case for herself,
                            whereas your only arguments are that what she's doing is [i]unethical[/i], and [i]wrong[/i].
                            But, as she argues, you may just [i]view[/i] it that way because you [b]are[/b] a kobold.
                        [/p]
                        [p]
                            As the both of you finish your drinks, the discussion winds down.
                            The canine rises from her seat, and escorts you to the door.
                            You try to [i]act[/i] as though you still condemn Cassidy's trade,
                            but deep down inside, you know you don't.
                            Not anymore.
                            Or at least [i]not as much[/i].
                            And it [b]shows[/b].
                            Besides, she very clearly [i]won[/i] the argument.
                            You can hate what she does all you'd like,
                            but that won't change the fact that she's undeniably in the right here.
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildContinueChoice() {
        var disabled = ctrl.postnotbarn.has() ? "disabled" : "";
        var isSelected = ctrl.postnotbarn.has();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildContinueChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerContinueListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.postnotbarn.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = "notBarnTeaDisagree";

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (ctrl.notbarn.get() !== NotBarnTeaDoorChoice.DISAGREE) {
            return "";
        }
        global.ui.applyTheme("hamlet_mansion");
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += ctrl.teaDisagreeChange();
        part += buildChoice();
        part += next.build();
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (ctrl.notbarn.get() !== NotBarnTeaDoorChoice.DISAGREE) {
            return;
        }

        next.registerListeners();

        if (ctrl.postnotbarn.has()) {
            return;
        }

        registerContinueListener();
    };
}
