/**
 * Buy section of the Workshop scene.
 * @param {SekiWorkshopController} controller The Seki controller.
 */
function SekiWorkshopBuy(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var continueId = "buyContinueButton";
    var next = new SekiWorkshopBuyContinue(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            After about a minute of waiting, you begin to get a bit impatient.
                            You ring the bell a few more times, until you finally get a response in the form of a raspy,
                            bass shout coming from the darkness on the far end of the counter:
                            "[color=brown]Hold your horses!
                            Settle down!
                            I'm on my way!
                            Can't an old man get a minute to finish grinding his herbs?!
                            You youngsters are always so [b]restive[/b]![/color]"
                        [/p]
                        [p]
                            Loudly grumbling, the elderly owl emerges from the shadows, stepping into the dim candlelight,
                            which illuminates his once-brown, but now pale grey feathers.
                            Readjusting the heavy, thick spectacles atop his beak,
                            the angry frown on the bird's face changes to a happy,
                            heartfelt smile as he realizes the tiny little thing that interrupted his machinations was none other but, well, [b]you[/b].
                        [/p]
                        [p]
                            "[color=brown]Ahhh!
                            My favorite customer!
                            Uhhh...[/color]"
                            The avian brings his feathery hand towards his forehead, wiping his brow as he visibly tries his very hardest to recall your name.
                            You know he didn't forget you.
                            His old mind just can't remember things quite as well as it used to.
                            You understand.
                            Returning a smile, you coyly hint that your name is ${ctrl.name()}.
                        [/p]
                        [p]
                            "[color=brown]Yes, yes!
                            ${ctrl.name()}!
                            I knew that!
                            I was just [b]catching my breath[/b] from walking all the way over here.[/color]"
                            Silly old geezer.
                            "[color=brown]Let me take a good look at you.[/color]"
                            He continues, leaning forwards over the counter, gazing down at you with his large owl eyes.
                        [/p]
                        `;
        if (ctrl.health() < 80) {
            toReturn += `[p] 
                            "[color=brown]You look like you've seen better days!
                            Who'd you get in a tussle with this time, eh?
                            It's probably best if you [b]don't[/b] tell me.
                            If they can beat up a fierce youngling like yourself, an old geezer like me wouldn't stand much of a chance.
                            Twenty years ago, I'd have shown those ruffians what-for, let me tell you![/color]"
                        [/p]`;
        } else {
            toReturn += `[p] 
                            "[color=brown]You look fit as ever!
                            Taking good care of yourself, eh?
                            'Atta ${ctrl.gender() === GenderEnum.MALE ? "boy" : "girl"}.
                            It'd pain an old man's heart to see a pretty little snout like yours get hurt.
                            Do me a favor and keep yourself out of harm's way, won't you?
                            Not for your sake, but for mine.[/color]"
                        [/p]`;
        }

        toReturn += `   [p]
                            Noticing your well-filled coin purse, the bird's smirk deepens.
                            "[color=brown]Come across some gold, now have you?
                            While I sometimes forget, I [i]am[/i] running a store here.
                            Feel free to browse, just don't sample anything without asking me first.[/color]"
                        [/p]
                        [p][sneak]
                            You are in a safe zone.
                            You can use items from your inventory here.
                            You are in a store.
                            You can sell items from your inventory here.
                            You may buy items from the list below.
                            Keep in mind that all purchases are final.
                            Worn equipment can not be sold.
                            Buying equipment will discard your previous attire.
                        [/sneak][/p]`;
        toReturn += ctrl.buy.getGenerator().build();
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.buy.continued();
        var choice = `<div class="choicecontainer">
                        <button class="button inlinechoice ${disabled ? "selected" : ""}" id="${continueId}" ${disabled ? "disabled" : ""}>
                            Continue
                        </button>
                      </div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerContinueListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.buy.continue();
            ctrl.buy.getGenerator().disable();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = "sekiBuy";

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (!ctrl.entrance.continued() || ctrl.gold() < ctrl.minBuyGold) {
            return "";
        }
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += buildChoice();
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (!ctrl.entrance.continued() || ctrl.gold() < ctrl.minBuyGold) {
            return;
        }

        next.registerListeners();

        if (ctrl.buy.continued()) {
            return;
        }

        registerContinueListener();
        ctrl.buy.getGenerator().registerListeners();
    };
}
