/**
 * The Home scene. One of the options following the Forest.
 */
function Home() {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var sceneId = "Home";
    var sceneNameUnsaved = "Home - Late";
    var sceneNameSaved = "Home - Early";
    var ctrl = new HomeController(sceneId);
    var saved = new HomeSaved(ctrl);
    var unsaved = new HomeUnsaved(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Returns true if the home was saved, and false otherwise.
     * @returns {boolean} True if the home was saved, and false otherwise.
     */
    function hasSaved() {
        var status = ctrl.status();
        return (status === HomeStatusEnum.SAVED);
    }

    /**
     * Sets this scene's name.
     */
    function setName() {
        var sceneName = hasSaved() ? sceneNameSaved : sceneNameUnsaved;
        that.name = sceneName;
    }

    /**
     * Sets all the required global variables such as scene id, scene name,
     * scene stack and theme.
     */
    function setGlobals() {
        global.currentScene = that.id;
        global.currentSceneName = that.name;
        global.currentSceneFolder = that.subfolder ? that.subfolder : "";
        global.kobold.history.addToSceneStack(that.id);
    }

    /**
     * Builds the tab as a HTML string.
     * @returns {string} The tab, as a HTML string.
     */
    function buildTab() {
        var tab = global.ui.buildGenericHeader();
        tab += global.parser.parse(`[t]home[/t]`);
        tab += hasSaved() ? saved.build() : unsaved.build();
        tab += global.ui.buildGenericFooter();
        return tab;
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = sceneId;
    this.name = "Error";

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Loads this scene.
     */
    this.load = function () {
        setName();
        setGlobals();
        var tab = buildTab();
        global.ui.loadToMain(tab);
        hasSaved() ? saved.registerListeners() : unsaved.registerListeners();
        ctrl.autoSave();
    };
}

(function () {
    var scene = new Home();
    global.sceneLoader.registerScene(scene.id, scene);
})();
