/**
 * To bed section of the home scene.
 * @param {HomeController} controller The home controller.
 */
function HomeAmbushToBed(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var continueId = `ambushWakeContinueButton`;
    var toWake = new HomeAmbushWakeUp(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            You begin to wake up a [b]long[/b] time later, your head absolutely [b]killing[/b] you.
                            Slowly regaining consciousness, you clutch your forehead, which feels like it was hit by a [b]catapult[/b].
                            The rear of your cranium, too, feels as though it's been through [b]hell[/b].
                            Carefully feeling around, 
                            your thoroughly rocked brain narrowly registers the small amount of cold, clotted
                            [b][color=red]blood[/color][/b] your fingers collect from around the gash at the back of your head.
                        [/p]
                        [p]
                            You wearily open your heavy eyelids, which are luckily greeted by night-time instead of the brightness of day.
                            You don't think you'd be able to process any vibrant colors right now.
                            Your brain struggles to cope with even the small amount of moonlight dropping in through the treetops.
                            At least you're still on the ground near your house.
                            Not being kidnapped is a good thing.
                        [/p]
                        [p]
                            Becoming aware of the blood on your fingers, you let out a pained groan.
                            You poke around your skull a bit more intently.
                            The aching wound seems to have closed on its own already, although you can't say for sure how much blood you lost.
                        [/p]
                        [p]
                            You examine the rest of your body.
                            Everything but your head seems to be intact.
                            Everything apart from your coin pouch, which you find on the ground next to you, completely emptied.
                        [/p]
                        [p]
                            You wince in pain as you slowly rise to your feet, steadying yourself against the tree you slammed into.
                            You feel like you're about to pass out again, but manage to collect yourself enough to stammer into your house.
                            Closing the wooden door behind you, you practically [b]drop[/b] onto the bale of hay that you call your [i]bed[/i], 
                            before losing consciousness once more.
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.saved.ambush.sleepContinued();
        var choice = `<div class="choicecontainer">
                        <button class="button inlinechoice ${disabled ? "selected" : ""}" id="${continueId}" ${disabled ? "disabled" : ""}>
                            Continue
                        </button>
                      </div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerContinueListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.saved.ambush.sleepContinue();
            loadNextPart(toWake);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = "homeAmbushBed";

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (!ctrl.saved.ambush.knockContinued()) {
            return "";
        }
        global.ui.applyTheme("home_night");
        var change = ctrl.saved.ambush.sleepChange(ctrl.gold());
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += change;
        part += buildChoice();
        part += toWake.build();
        part += `</div>`;

        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (!ctrl.saved.ambush.knockContinued()) {
            return;
        }

        toWake.registerListeners();

        if (ctrl.saved.ambush.sleepContinued()) {
            return;
        }

        registerContinueListener();
    };
}
