/**
 * Hide section of the home scene.
 * @param {HomeController} controller The home controller.
 */
function HomeHide(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var toBed = new HomeHideToBed(ctrl);
    
    var continueId = `homeHideContinue`;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            You're [i]smart[/i].
                            If you approach the debt collector with a bag of gold strapped around your neck,
                            he'll most certainly take it from you, to [i]settle the score[/i].
                            But, if you [i]don't have[/i] any gold to give, then he can't [i]take[/i] any.
                            Screw smart.
                            You're a [b]genius[/b].
                        [/p]
                        [p]
                            You take off your pouch of gold, dig a small hole into the ground, and bury it right next to a tree,
                            the loose dirt concealed by a small bush.
                            With your purse hidden, you approach the kobold-pig hybrid with a smug smirk plastered across your face.
                        [/p]
                        [p]
                            "[color=brown][b]You're late.[/b][/color]" the brute speaks, in a deep and bass voice.
                            He rises from his treestump-seat as you approach, towering a good foot above you,
                            undoubtebly weighing multiple times your own mass.
                            "[color=brown][b]Rat wants his money. I'm here to collect.[/b][/color]" the fat lizard continues, scratching his bulging belly.
                        [/p]
                        [p]
                            You calmly and clearly explain that you don't really [i]have[/i] any coins for the half-pig to collect.
                            The big kobold snorts loudly, staring down at you with a hateful glare on his face.
                            He loudly cracks his knuckles, hands balling up into fists.
                            You suddenly realize that you haven't really thought this plan all the way through.
                            Perhaps you aren't as much of a genius as you hoped you were.
                        [/p]
                        [p]
                            Out of the corner of your eye, you spot the motion of a burly arm swinging upwards,
                            but the bandit's scaly fist plows into the underside of your muzzle before you manage to react.
                            The hefty, unexpected uppercut knocks you off of your feet.
                            You fall backwards, onto the leafy forest floor, a bit of blood spilling from your maw onto the ground.
                        [/p]
                        [p]
                            Even as your body comes to a rest, your brain still can't fully comprehend what exactly just happened.
                            Only when the kobold hybrid straddles your chest, pinning you down with the full weight of his relatively [b]enormous[/b] body,
                            does fear begin to emerge at the back of your mind.
                            For a moment, you consider telling him about your buried gold, yet before you can so much as open your mouth,
                            the savage mercilessly begins to [b]wail[/b] on you, brutally bashing your face, 
                            alternating between both of his hands to keep the steady stream of violence coming.
                        [/p]
                        [p]
                            Your mind spaces out, seemingly [i]leaving[/i] your body as your head gets violently [b]thrashed[/b].
                            You wake up from your preservation instinct-induced blackout as the burly ruffian rises from your body,
                            huffing and panting from the vicious beatdown.
                        [/p]
                        [p]
                            Your face is in agonizing pain.
                            Your eyes are [b]punched[/b] shut.
                            You spit out the chipped remains of what was once one of your teeth.
                            You can barely breathe through the blood oozing from your snout, a lot of which is piling up at the back of your throat.
                            You roll onto your side, just to let some of it seep from your mouth more easily.
                        [/p]
                        [p]
                            He's still not quite yet done.
                            With a loud, angry growl, the enforcer ruthlessly [b]kicks[/b] you in the gut, his foot [b]burying[/b] into your unprotected belly,
                            knocking the air out of your meagre frame.
                            You cough up a considerable amount of blood, as your constant flow of tears intensifies.
                            Breathing raggedly, panting for air and whimpering for mercy, you curl up into a ball as the half-kobold retracts his foot.
                        [/p]
                        [p]
                            The debt collector snorts yet again, before hocking down a disgusting wad of phlegm, directly onto of your face.
                            "[color=brown][b]You're lucky I don't get paid enough to kill.[/b][/color]" he says, flexing his fingers and wiping your blood from his knuckles.
                            "[color=brown][b]Others do. Watch your back.[/b][/color]" 
                            With those words uttered, the sadistic pig walks away, leaving you a bloodied and broken mess, idly sobbing on the leafy forest floor.
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.saved.hide.ballContinued();
        var choice = `<div class="choicecontainer">
                        <button class="button inlinechoice ${disabled ? "selected" : ""}" id="${continueId}" ${disabled ? "disabled" : ""}>
                            Continue
                        </button>
                      </div>`;
        return choice;
    }
    
    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerContinueListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.saved.hide.ballContinue();
            loadNextPart(toBed);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = "homeHide";

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (ctrl.saved.getApproachChoice() !== HomeSavedChoice.HIDE) {
            return "";
        }
        var change = ctrl.saved.hide.ballChange();
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += change;
        part += buildChoice();
        part += toBed.build();
        part += `</div>`;

        // BUILD CHILDREN HERE

        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (ctrl.saved.getApproachChoice() !== HomeSavedChoice.HIDE) {
            return;
        }
        
        toBed.registerListeners();

        if (ctrl.saved.hide.ballContinued()) {
            return;
        }

        registerContinueListener();
    };
}
